/***************************************************************************
                splashscreen.h  -  description
                             -------------------
    begin                : Sun Feb 16 2003
    copyright            : (C) 2003 by Paul-henri ferme
    email                : paul-henri.ferme@noos.fr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SPLASHSCREEN_H
#define SPLASHSCREEN_H

#include <qpixmap.h>
#include <qwidget.h>

class SplashScreen : public QWidget {
public:
    SplashScreen( const QPixmap &pixmap );

    void setStatus( const QString &message, int alignment = AlignLeft, const QColor &color = black );
    void finish( QWidget *mainWin );
    void repaint();

protected:
    void mousePressEvent( QMouseEvent * );

private:
    QPixmap pix;
};

#endif
